==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource.md <==
# AwsCloudMapResource


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')
```



| Illustration | AwsCloudMapResource | AwsCloudMapResourceCard | AwsCloudMapResourceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource.png) | ![illustration for AwsCloudMapResource](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource.Local.png) | ![illustration for AwsCloudMapResourceCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResourceCard.Local.png) | ![illustration for AwsCloudMapResourceGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResourceGroup.Local.png) |




## AwsCloudMapResource

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResource
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResource('AwsCloudMapResource', 'Aws Cloud Map Resource', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResource
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResource('AwsCloudMapResource', 'Aws Cloud Map Resource', 'an optional tech label')
@enduml
```

## AwsCloudMapResourceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceCard('AwsCloudMapResourceCard', 'Aws Cloud Map Resource Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceCard('AwsCloudMapResourceCard', 'Aws Cloud Map Resource Card', 'an optional description')
@enduml
```

## AwsCloudMapResourceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceGroup('AwsCloudMapResourceGroup', 'Aws Cloud Map Resource Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceGroup('AwsCloudMapResourceGroup', 'Aws Cloud Map Resource Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource.md <==
# AwsCloudMapResource


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')
```



| Illustration | AwsCloudMapResource | AwsCloudMapResourceCard | AwsCloudMapResourceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource.png) | ![illustration for AwsCloudMapResource](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource.Local.png) | ![illustration for AwsCloudMapResourceCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResourceCard.Local.png) | ![illustration for AwsCloudMapResourceGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResourceGroup.Local.png) |




## AwsCloudMapResource

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResource
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResource('AwsCloudMapResource', 'Aws Cloud Map Resource', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResource
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResource('AwsCloudMapResource', 'Aws Cloud Map Resource', 'an optional tech label')
@enduml
```

## AwsCloudMapResourceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceCard('AwsCloudMapResourceCard', 'Aws Cloud Map Resource Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceCard('AwsCloudMapResourceCard', 'Aws Cloud Map Resource Card', 'an optional description')
@enduml
```

## AwsCloudMapResourceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceGroup('AwsCloudMapResourceGroup', 'Aws Cloud Map Resource Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudMapResourceGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AwsCloudMapResource')

' renders the element
AwsCloudMapResourceGroup('AwsCloudMapResourceGroup', 'Aws Cloud Map Resource Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
